package com.ruoyi.frequency.workspanorama.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.ruoyi.frequency.workspanorama.entity.WorksPanorama;

import java.util.List;

/**
 * 作品和全景图关联Service接口
 * 
 * @author zj
 * @date 2023-09-22
 */
public interface WorksPanoramaService extends IService<WorksPanorama>
{
    /**
     * 查询作品和全景图关联
     * 
     * @param id 作品和全景图关联主键
     * @return 作品和全景图关联
     */
    public WorksPanorama selectWorksPanoramaById(Long id);

    /**
     * 查询作品和全景图关联列表
     * 
     * @param worksPanorama 作品和全景图关联
     * @return 作品和全景图关联集合
     */
    public List<WorksPanorama> selectWorksPanoramaList(WorksPanorama worksPanorama);

    /**
     * 新增作品和全景图关联
     * 
     * @param worksPanorama 作品和全景图关联
     * @return 结果
     */
    public int insertWorksPanorama(WorksPanorama worksPanorama);

    /**
     * 修改作品和全景图关联
     * 
     * @param worksPanorama 作品和全景图关联
     * @return 结果
     */
    public int updateWorksPanorama(WorksPanorama worksPanorama);

    /**
     * 批量删除作品和全景图关联
     * 
     * @param ids 需要删除的作品和全景图关联主键集合
     * @return 结果
     */
    public int deleteWorksPanoramaByIds(Long[] ids);

    /**
     * 删除作品和全景图关联信息
     * 
     * @param id 作品和全景图关联主键
     * @return 结果
     */
    public int deleteWorksPanoramaById(Long id);
}
